<?php

namespace AuthStack\Installer\Facade;

use Illuminate\Support\Facades\Facade;


class MySQLConnectionChecker extends Facade
{
    protected static function getFacadeAccessor()
    {
        return 'MySQLConnectionChecker';
    }
}